==> jis-1.0.26.tgz: package/src/Is.ts <==
export default class Is{
    private static callToString(arg:any) {
        return Object.prototype.toString.call(arg)
    }
    static $string(arg:any) {
        return Is.callToString(arg) === '[object String]';
    }
    static is(arg:any, type){
        let response = false;
        if (Is.$string(type))
            response = Is.callToString(arg) === `[object ${type}]`;
        else if(Is.$function(type))
            response = arg instanceof type;
        return response;
    }
    static $array(arg:any){
        return Is.is(arg, 'Array');
    }
    static $null(arg:any){
        return Is.is(arg, 'Null');
    }
    static $number(arg:any){
        return Is.is(arg, 'Number');
    }
    static $object(arg:any){
        return Is.is(arg, 'Object');
    }
    static $undefined(arg:any){
        return Is.is(arg, 'Undefined');
    }
    static $boolean(arg:any){
        return Is.is(arg, 'Boolean');
    }
    static $function(arg:any){
        return Is.callToString(arg) === '[object Function]';
    }
    static isValidObject(data:object, rules:object) {
        if (!Is.$object(data)) throw new Error('The data parameter must be an Object');
        if (!Is.$object(rules)) throw new Error('The rules parameter must be an Object');

        let $response = true;
        let $keys = Object.getOwnPropertyNames(rules);

        for (let key of $keys) {
            if (!$response) break;
            let rule = rules[key];
            if (Is.$array(rule)) {
                if (rule.length < 1) continue;
                let parcial = false;
                for (let _rule of rule) {
                    if (parcial) break;
                    parcial = parcial || Is.is(data[key], _rule);
                }
                $response = $response && parcial;
            }
            else $response = $response && Is.is(data[key], rule);
        }
        return $response;
    }
    static $numeric(arg){
        if (Is.$number(arg))
            return true;
        if (Is.$string(arg))
            return /^[+\-]?[0-9]+\.?([0-9]+)?([eE][+\-]?[0-9]+)?$/.test(arg);
        return false;
    }
}

==> jis-1.0.30.tgz: package/src/Is.ts <==
export default class Is{
    private static callToString(arg:any) {
        return Object.prototype.toString.call(arg)
    }

    static $string(arg:any) {
        return Is.callToString(arg) === '[object String]';
    }

    static is(arg:any, type){
        if(Is.$function(type))
        {
            return arg instanceof type;
        }

        if (Is.$string(type))
        {
            return  Is.callToString(arg) === `[object ${type}]`;
        }

        return arg === type;
    }

    static $array(arg:any){
        return Is.is(arg, 'Array');
    }

    static $null(arg:any){
        return Is.is(arg, 'Null');
    }

    static $number(arg:any){
        return Is.is(arg, 'Number');
    }

    static $object(arg:any){
        return Is.is(arg, 'Object');
    }

    static $undefined(arg:any){
        return Is.is(arg, 'Undefined');
    }

    static $boolean(arg:any){
        return Is.is(arg, 'Boolean');
    }

    static $function(arg:any){
        return Is.callToString(arg) === '[object Function]';
    }

    static objectIsValid(data:object, rules:object) {
        if (!Is.$object(data)) throw new Error('The data parameter must be an Object');
        if (!Is.$object(rules)) throw new Error('The rules parameter must be an Object');

        let $response = true;
        let $keys = Object.getOwnPropertyNames(rules);

        $keys.forEach((key) => {
            let rule = rules[key];
            if (Is.$array(rule)) {
                if (rule.length < 1) return;
                let parcial = false;
                rule.forEach((_rule) => {
                    parcial = parcial || Is.is(data[key], _rule);
                });
                return $response = $response && parcial;
            }
            $response = $response && Is.is(data[key], rule);
        });
        return $response;
    }

    static $numeric(arg: any)
    {
        if (Is.$number(arg))
        {
            return true;
        }

        let $arg = String(arg || '');
        let regex = /^[-+]?(([0-9]+)|([0-9]*(\.[0-9]+))|([0-9]+\.))([Ee]([-+]?[0-9]+))?$/g;

        return regex.test( $arg );
    }
}
